@@ -13,6 +13,8 @@ API_CONSUMPTION = "consumption"
 API_RESOURCE_ID = "resourceId"
 API_RESOURCE_NAME = "name"
 
+API_RESPONSE_AUTH_EXPIRE = "exp"
+API_RESPONSE_AUTH_VALID = "valid"
 API_RESPONSE_CURRENT_RATES = "currentRates"
 API_RESPONSE_DATA = "data"
 API_RESPONSE_LAST_TIME = "lastTs"
